import { useState } from "react";
import { useForm } from "react-hook-form";
import "./promoStyle.css";
import { NavLink } from 'react-router-dom';
import Config from '../../config';
import { useHistory } from 'react-router'

export default function PromotionUpdateFormComponent(props) {
    const { register, handleSubmit, formState: { errors } } = useForm();
    const history = useHistory();
    const [serverErrors, setErrors] = useState([]);

    const onSubmit = (data) => {
        console.log(data)

        fetch(`${Config.promotionsUrl}/${data.promotionId}`, {
            method: "PUT",
            headers: {
                "Content-Type": "application/json",
            },
            body: JSON.stringify(data),
        })
            .then(res => res.ok ? history.push("/promos") : setErrors(["error"]))
            .catch(err => setErrors([err.message]))
    };
    console.log(props.location.state.promo.promotionId)
    return (
        <div>
            <div className="promo-container">
                <div className="promo-form-container">
                    <h1 className="promo-form-title">Update Promotion</h1>
                    <form className="promo-form" onSubmit={handleSubmit(onSubmit)}>
                        {serverErrors.length ? <p className="form-error">{serverErrors}</p> : ""}

                        <div className="form-group">
                            <label>Promotion Id</label>
                            <input
                                {...register("promotionId", {
                                    value: props.location.state.promo.promotionId,
                                    required: "promotion id is required",
                                    maxLength: { value: 10, message: "You exceeded the maximum value" },
                                    
                                })}
                                readOnly
                                id="promotionId"
                                className="form-control"
                                placeholder="eg. PROMO-403"
                                
                            />
                            {errors.promotionId && <p className="form-error">{errors.promotionId.message}</p>}

                        </div>
                        <div className="form-group">
                            <label>Product Sku</label>
                            <input
                                {...register("productSku", {
                                    value: props.location.state.promo.productSku,
                                    required: "product sku required",
                                    maxLength: { value: 10, message: "You exceeded the maximum value" }
                                })}
                                id="productSku"
                                className="form-control"
                            />
                            {errors.productSku && <p className="form-error">{errors.productSku.message}</p>}
                            <br></br>
                        </div>

                        <div className="form-group">
                            <label>Enter % off</label>
                            <div className="input-group">

                                <div className="input-group-prepend">
                                    <span className="input-group-text">%</span></div>
                                <input
                                    {...register("discountPercentage", {
                                        valueAsNumber: true,
                                        value: props.location.state.promo.discountPercentage,
                                        required: "% off required",
                                        min: { value: 0, message: "% must be greater than or equal to 0" },
                                        max: { value: 100, message: "% must be less than or equal to 100" },
                                    })}
                                    id="discountPercentage"
                                    className="form-control"
                                    placeholder={props.location.state.promo.discountPercentage }
                                    type="number"
                                />
                            </div>
                            {errors.discountPercentage && <p className="form-error">{errors.discountPercentage.message}</p>}

                        </div>

                        <div className="form-group">
                            <label>Applies at Minimum Quantity</label>
                            <input
                                {...register("minimumQuantity", {
                                    valueAsNumber: true,
                                    value: props.location.state.promo.minimumQuantity,
                                    required: "minimum quantity is required",
                                    min: { value: 1, message: "discount percentage must be greater than 0" },
                                })}
                                id="minimumQuantity"
                                className="form-control"
                                type="number"
                                min="1"
                                placeholder={props.location.state.promo.minimumQuantity}
                            />
                            {errors.minimumQuantity && <p className="form-error">{errors.minimumQuantity.message}</p>}
                        </div>
                        <input className="promo-submit" type="submit" value="Update Promotion" />
                        <NavLink className="promo-cancel" to="/promos">Cancel</NavLink>
                    </form>
                </div>
            </div>
        </div>
    );
}

